TypeInfo

Struct TypeInfo 

#[non_exhaustive]
pub struct TypeInfo { pub cached_big: OnceLock<bool>, pub deserialize_cached_term_into_buckets: fn(&CachedTerm, &mut ErasedTermBuckets) -> bool, pub erased_bucket_ops: ErasedBucketOps, pub name: &'static str, pub trivial: bool, pub type_former: PrecomputedTypeFormer, pub vertex: Vertex, }
Fully computed reflection metadata for one concrete type.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
cached_big: OnceLock<bool>

If this is a “big” type: either inductive or contains a big type.

deserialize_cached_term_into_buckets: fn(&CachedTerm, &mut ErasedTermBuckets) -> bool

Decode one cached term of this type and push it into erased term buckets.

erased_bucket_ops: ErasedBucketOps

Erased bucket operations for values of this concrete type.

name: &'static str

The pretty-printed name of this type.

trivial: bool

Whether this type is uninteresting: specifically, whether it is either non-inductive or a trivial wrapper around exactly one (other) type. Note that uninstantiable types are interesting, i.e. nontrivial.

type_former: PrecomputedTypeFormervertex: Vertex

The union and intersection of the bag of types that may be contained in a value of this type.

Implementations

Source

impl TypeInfo

pub fn instantiable(&self, visited: &mut BTreeSet<Type>) -> bool

Whether this type is instantiable, i.e. has at least one instantiable constructor.

pub fn is_big(&self) -> bool

Whether Self either is inductive or contains a big type.