Sigma

Struct Sigma 

#[repr(transparent)]
pub struct Sigma<T, P: Predicate<T>> { pub value: T, /* private fields */ }
Sigma-types: types whose terms satisfy a predicate (e.g. floats greater than zero).

Fields

value: T

A value of type T that additionally satisfies the predicate P.

Implementations

Source

impl<T, P: Predicate<T>> Sigma<T, P>

pub fn new(candidate: T) -> Result<Self, (P::Error, T)>

Attempt to create a new term of this Sigma-type by checking the predicate and succeeding iff the predicate holds.

Errors

If the property does not hold for the candidate provided.

pub unsafe fn new_unchecked(candidate: T) -> Self

Attempt to create a new term of this Sigma-type by checking the predicate and succeeding iff the predicate holds.

Safety

Nonsensical value if the property does not hold for the candidate provided.

Panics

If debug assertions are enabled and P::check fails.