Crate pbt

Crate pbt 

Modules

cache
construct
multiset
reflection
search
shrink
sigma
Sigma-types: types whose terms satisfy a predicate (e.g. floats greater than zero).
size

Macros

arbitrary_nonzero_unsigned
Generate an arbitrary nonzero value for an unsigned integer of fixed but unspecified width.
arbitrary_unsigned
Generate an arbitrary value for an unsigned integer of fixed but unspecified width.

Structs

StronglyConnectedComponents
Disjoint sets of mutually inductive types, represented using the standard Union-Find algorithm.
WyRand
A Pseudorandom Number generator, powered by the wyrand algorithm. This generator is based on the final v4.2 reference implementation.

Constants

SEED
The 16-bit hash seed, to be zero-extended for various platforms.

Derive Macros

Pbt
Derive all necessary traits in the pbt crate.