#[non_exhaustive]pub struct TypeInfo {
pub cached_big: OnceLock<bool>,
pub deserialize_cached_term_into_buckets: fn(&CachedTerm, &mut ErasedTermBuckets) -> bool,
pub erased_bucket_ops: ErasedBucketOps,
pub name: &'static str,
pub trivial: bool,
pub type_former: PrecomputedTypeFormer,
pub vertex: Vertex,
}Expand description
Fully computed reflection metadata for one concrete type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cached_big: OnceLock<bool>If this is a “big” type: either inductive or contains a big type.
deserialize_cached_term_into_buckets: fn(&CachedTerm, &mut ErasedTermBuckets) -> boolDecode one cached term of this type and push it into erased term buckets.
erased_bucket_ops: ErasedBucketOpsErased bucket operations for values of this concrete type.
name: &'static strThe pretty-printed name of this type.
trivial: boolWhether this type is uninteresting: specifically, whether it is either non-inductive or a trivial wrapper around exactly one (other) type. Note that uninstantiable types are interesting, i.e. nontrivial.
type_former: PrecomputedTypeFormervertex: VertexThe union and intersection of the bag of types that may be contained in a value of this type.
Implementations